@@ -1,8 +1,8 @@
-/* Smail SCCS ID: @(#)pd/pathalias/addlink.c	1.2 11/4/91 00:43:11 */
+/* Smail SCCS ID: @(#) $Id: addlink.c,v 1.3 1994/10/17 17:03:34 nm4 Exp $ */
 
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#)addlink.c	9.7 88/06/10";
+static char	*sccsid = "@(#) $Id: addlink.c,v 1.3 1994/10/17 17:03:34 nm4 Exp $";
 #endif /* lint */
 
 #include "def.h"
