@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#)pd/pathalias/local.c	1.2 %G 00:43:26 */
+/* Smail SCCS ID: @(#) $Id: local.c,v 1.3 1994/10/18 13:28:12 nm4 Exp $ */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#)local.c	9.2 88/06/10";
+static char	*sccsid = "@(#) $Id: local.c,v 1.3 1994/10/18 13:28:12 nm4 Exp $";
 #endif /* lint */
 
 #include <stdio.h>
