@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#)pd/pathalias/makedb.c	1.5 %G 11:14:17 */
+/* Smail SCCS ID: @(#) $Id: makedb.c,v 1.6 1994/10/18 13:28:12 nm4 Exp $ */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#)makedb.c	9.1 87/10/04";
+static char	*sccsid = "@(#) $Id: makedb.c,v 1.6 1994/10/18 13:28:12 nm4 Exp $";
 #endif /* lint */
 
 #include <stdio.h>
