@@ -1,7 +1,7 @@
-/* Smail SCCS ID: @(#)pd/pathalias/mapaux.c	1.7 %G 13:57:32 */
+/* Smail SCCS ID: @(#) $Id: mapaux.c,v 1.8 1994/10/18 13:28:12 nm4 Exp $ */
 /* pathalias -- by steve bellovin, as told to peter honeyman */
 #ifndef lint
-static char	*sccsid = "@(#)mapaux.c	9.4 89/03/01";
+static char	*sccsid = "@(#) $Id: mapaux.c,v 1.8 1994/10/18 13:28:12 nm4 Exp $";
 #endif /* lint */
 
 #include "def.h"
