@@ -34,7 +34,7 @@ extern void free();
 #ifdef POSIX_OS
 #include <unistd.h>
 #else
-/* extern long lseek(); */
+extern long lseek();
 #endif
 
 /*
