@@ -1,4 +1,4 @@
-/* @(#)src/config.c	1.15 9/16/92 09:10:20 */
+/* @(#) $Id: config.c,v 1.17 1994/10/24 13:13:09 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -45,6 +45,10 @@ int message_log_mode = MESSAGE_LOG_MODE; /* mode for per-message log files */
 int spool_grade = SPOOL_GRADE;		/* default spool grade character */
 int open_retries = OPEN_RETRIES;	/* max open retries on config files */
 int open_interval = OPEN_INTERVAL;	/* sleep between open retries  */
+int min_runq_grade;			/* minimum grade to process in queue run */
+int max_runq_grade;			/* maximum grade to process in queue run */
+int min_delivery_grade;			/* minimum grade to deliver */
+int max_delivery_grade;			/* maximum grade to deliver */
 char *config_file = CONFIG_FILE;	/* config file name */
 char *director_file = DIRECTOR_FILE;	/* directors file name */
 char *router_file = ROUTER_FILE;	/* routers file name */
@@ -73,6 +77,8 @@ int lock_by_name = LOCK_BY_NAME;	/* TRUE to use spool lockfiles */
 int queue_only = FALSE;			/* TRUE to default to -Q flag */
 int max_hop_count = MAX_HOP_COUNT;	/* fail if hop_count exceeds this */
 char *delivery_mode_string = DELIVERY_MODE; /* string naming delivery mode */
+char *delivery_grades = DELIVERY_GRADES;/* the msg grade range to be delivered */
+char *runq_grades = RUNQ_GRADES;	/* the msg grade range in runq */
 char *smart_user = CONFIG_SMART_USER;	/* default user for smartuser */
 char *smart_path = CONFIG_SMART_PATH;	/* default path for smarthost */
 char *smart_transport = CONFIG_SMART_TRANSPORT;	/* transport for smarthost */
@@ -103,3 +109,4 @@ char *auth_domains = AUTH_DOMAINS;	/* authoritative domain list */
 int tzoffset = 0;			/* glotznet host timezone offset */
 int tznodst = 0;			/* glotznet does not have DST */
 #endif /* GLOTZNET */
+int rfc1413_query_timeout = -1;		/* Timeout on RFC1413 queries - initially disabled */
