@@ -1,4 +1,4 @@
-/* @(#)src/config.h	1.28 9/16/92 09:10:22 */
+/* @(#) $Id: config.h,v 1.30 1994/10/26 14:14:22 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -1006,23 +1006,17 @@ id $message_id; $spool_date"
  *	     the ending nul byte in the length of keys.  There is a
  *	     tool distributed with smail (mkline) that can be used to
  *	     create regular YP databases, for use with the `yp' proto.
+ * nialias - use NeXTs netinfo mail alias table
+ * nisplus - use Sun's NIS+ (the follow-on to YP) for remote table access.
  *
  * #define ALIASES_FILE	"/usr/lib/smail/aliases" (* Suggestion *)
  * #define ALIASES_FILE	"/usr/smail/lib/aliases" (* alternate *)
  */
 #if	!defined(ALIASES_FILE) && !defined(NO_ALIASES_FILE)
-# ifdef HAVE_YP
-#  define ALIASES_FILE "mail.aliases"	/* Standard YP aliases map */
-# else
-#  define ALIASES_FILE "/usr/lib/aliases" /* sendmail compatible name */
-# endif
+# define ALIASES_FILE "/usr/lib/aliases" /* sendmail compatible name */
 #endif
 #ifndef	ALIASES_PROTO
-# ifdef HAVE_YP
-#  define ALIASES_PROTO "aliasyp"	/* use Sun's YP aliases service */
-# else
-#  define ALIASES_PROTO "lsearch"	/* This should work on any UN*X os */
-# endif
+# define ALIASES_PROTO "lsearch"	/* This should work on any UN*X os */
 #endif
 
 /*
@@ -1044,7 +1038,7 @@ id $message_id; $spool_date"
  * host may be down.  To enable this behavior, define the name below.
  */
 #if	!defined(ALIASES_TRYAGAIN) && !defined(NO_ALIASES_TRYAGAIN)
-# ifdef HAVE_YP
+# if defined(HAVE_YP) || defined(HAVE_NISPLUS)
 #  define ALIASES_TRYAGAIN		/*  */
 # endif
 #endif
@@ -1505,3 +1499,23 @@ id $message_id; $spool_date"
 #  define USE_SMTP_TRANSPORT
 # endif
 #endif
+
+/*
+ * Delivery control by message grade
+ *
+ * runq_grades variable defines which messages are processed
+ * during a queue run (selected by grades).  Only the grades in the
+ * simple grade range (ie "a-z", no commas etc....)  will be processed.
+ * The default value for this is NULL (or "-") - meaning all grades.
+ *
+ * The delivery_grades variable similarly defines a range of grades
+ * which will be delivered immediately, rather than queued up for
+ * later transmission.
+ */
+#ifndef RUNQ_GRADES
+# define RUNQ_GRADES NULL		/*  */
+#endif
+
+#ifndef DELIVERY_GRADES
+# define DELIVERY_GRADES NULL		/*  */
+#endif
