@@ -1,4 +1,4 @@
-/* @(#)src/directors/fwdfile.c	1.9 9/20/92 12:54:41 */
+/* @(#) $Id: fwdfile.c,v 1.11 1994/10/28 16:06:35 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -92,6 +92,7 @@
 #include "../direct.h"
 #include "../dys.h"
 #include "../exitcodes.h"
+#include "../main.h"
 #include "fwdfile.h"
 #ifndef DEPEND
 # include "../extern.h"
@@ -377,7 +378,7 @@ finish_forward(dp, addr, new, defer, fail)
 {
     register struct forwardfile_private *priv;
     char *fn;				/* name of forward file */
-    int fd;				/* open forward file */
+    FILE *fp;				/* open forward file */
     struct stat statbuf;		/* buf for fstat call */
     char *buf;				/* buffer for file contents */
     struct addr *cur;			/* addrs from process_field */
@@ -465,8 +466,7 @@ finish_forward(dp, addr, new, defer, fail)
     }
 
     DEBUG1(DBG_DRIVER_MID, "dtd_forwardfile:  opening forward file %s\n", fn);
-    fd = open(fn, 0);
-    if (fd < 0) {
+    if (( fp = fopen_as_user(fn, "r", 1, addr->uid, addr->gid)) == (FILE*) 0 ) {
 	xfree(fn);
 	DEBUG1(DBG_DRIVER_HI, "dtd_forwardfile:  no forward file for %s\n",
 	       addr->remainder);
@@ -475,13 +475,13 @@ finish_forward(dp, addr, new, defer, fail)
 
     /* find out how big the file is, malloc that much and read the file */
 #ifdef lock_fd_rd_wait
-    lock_fd_rd_wait(fd);
+    lock_fd_rd_wait(fileno(fp));
 #endif
-    (void) fstat(fd, &statbuf);
+    (void) fstat(fileno(fp), &statbuf);
 
     /* ignore non-files and ignore zero-length forward files */
     if ((statbuf.st_mode & S_IFMT) != S_IFREG || statbuf.st_size == 0) {
-	(void) close(fd);
+	(void) fclose(fp);
 	xfree(fn);
 	return FAIL;
     }
@@ -489,22 +489,61 @@ finish_forward(dp, addr, new, defer, fail)
     /* set security bits appropriately */
     flags |= forward_secure(dp, addr, &statbuf, fn);
 
+    if ((flags & ADDR_UNSECURE) ||
+        ((flags & ADDR_CAUTION) && ! (dp->flags & NOBODY_DIRECTOR)))
+    {
+        /*
+         * ERR_104 - security violation
+         *
+         * DESCRIPTION
+         *      A questionable address was supplied from a director
+         *      that is not allowed to supply a file command or
+         *      mailing list.
+         *
+         * ACTIONS
+         *      mail is sent to the address owner or to the
+         *      postmaster.
+         *
+         * RESOLUTION
+         *      The owner or postmaster should check the source source
+         *      of addresses against any file ownership restrictions
+         *      named in the director.
+         */
+        addr->error = note_error(ERR_NPOWNER|ERR_104,
+                                 xprintf("director %s: security violation",
+                                         dp->name));
+        addr->succ = *fail;
+        *fail = addr;
+        return;
+    }
+    if (flags & ADDR_CAUTION) {
+        /* be cautious of addresses, but nobody is set */
+        if (operation_mode != VERIFY_ADDRS &&
+            operation_mode != TEST_MODE)
+        {
+            write_log(LOG_SYS,
+                "%s ... director %s: child of %s insecure, access as 'nobody'",
+                      addr->in_addr,
+                      dp->name,
+                      addr->parent->in_addr);
+        }
+    }
+
     if (dp->flags & FWD_FORWARDTO) {
-	register FILE *f = fdopen(fd, "r");
 	register int c;
 
 	STR_INIT(&fwdtobuf);
-	while ((c = getc(f)) != EOF && c != '\n') {
+	while ((c = getc(fp)) != EOF && c != '\n') {
 	    STR_NEXT(&fwdtobuf, c);
 	}
-	if (ferror(f)) {
+	if (ferror(fp)) {
 	    write_log(LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
-	    (void) fclose(f);
+	    (void) fclose(fp);
 	    xfree(fn);
 	    STR_FREE(&fwdtobuf);
 	    return FAIL;
 	}
-	(void) fclose(f);
+	(void) fclose(fp);
 	STR_NEXT(&fwdtobuf, '\0');
 	if (strncmpic(fwdtobuf.p, "forward to ",
 		      sizeof("forward to ") - 1) != 0) {
@@ -517,15 +556,15 @@ finish_forward(dp, addr, new, defer, fail)
     } else {
 	buf = xmalloc(statbuf.st_size + 1); /* leave room for trailing nul */
 
-	if (read(fd, buf, statbuf.st_size) < statbuf.st_size) {
+	if (fread(buf, statbuf.st_size, 1, fp) < 1) {
 	    write_log(LOG_SYS, "read failed on %s, director=%s", fn, dp->name);
-	    (void) close(fd);
+	    (void) fclose(fp);
 	    xfree(buf);
 	    xfree(fn);
 	    return FAIL;
 	}
 
-	(void) close(fd);		/* don't need the open file anymore */
+	(void) fclose(fp);		/* don't need the open file anymore */
 
 	buf[statbuf.st_size] = '\0';	/* terminate the buffer */
 	DEBUG1(DBG_DRIVER_HI, "read %d bytes\n", statbuf.st_size);
@@ -743,6 +782,7 @@ secure_match(string, user, dirn)
     char *delim;
     struct passwd *pw;
 
+    delim=(char*)0;
     if (string[0] == '~' || string[0] == '/') {
 	/* hmm, looks sort of like a directory name, expand it */
 	char *dir = expand_string(string, (struct addr *)NULL,
