@@ -1,4 +1,4 @@
-/* @(#)src/directors/smartuser.c	1.4 7/11/92 11:48:42 */
+/* @(#) $Id: smartuser.c,v 1.5 1994/10/17 17:04:24 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -197,9 +197,16 @@ dtv_smartuser(dp, in, retry, okay, defer, fail)
 {
     register struct addr *cur;		/* temp for processing input */
     struct addr *next;			/* next addr to process */
+    struct smartuser_private *priv = (struct smartuser_private *)dp->private;
 
     DEBUG(DBG_DRIVER_HI, "dtv_smartuser called\n");
 
+    if (priv->new_user == NULL && smart_user == NULL) {
+	    /* smart-user director is not enabled */
+	    insert_addr_list(in, retry, (struct error *)NULL);
+	    return;
+    }
+
     /* loop through all of the input addrs */
     for (cur = in; cur; cur = next) {
 	char *remainder;		/* remainder from addr structure */
