@@ -1,4 +1,4 @@
-/* @(#)src/error.h	1.7 9/20/92 12:54:47 */
+/* @(#) $Id: error.h,v 1.10 1994/10/24 12:34:55 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -89,7 +89,10 @@
 #define ERR_172		172L		/* no connection to remote SMTP */
 #define ERR_173		173L		/* retry time expired */
 #define ERR_174		174L		/* retry interval not reached */
+#define ERR_175		175L		/* host locked */
+#define ERR_176         176L            /* greybook hosts file lookup error */
+#define ERR_177         177L            /* BIND - CNAME loop */
+#define ERR_178		178L		/* host not found in the DNS */
 #define ERR_1000	1000L		/* bad entry in reroute database */
 #define ERR_1001	1001L		/* failed to open reroute database */
 #define ERR_1002	1002L		/* reroute file lookup error */
-#define ERR_175		175L		/* host locked */
