@@ -1,4 +1,4 @@
-/* @(#)src/extern.h	1.34 9/20/92 18:44:03 */
+/* @(#) $Id: extern.h,v 1.36 1994/10/24 13:12:25 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -43,6 +43,10 @@ extern int message_log_mode;		/* mode for per-message log files */
 extern int spool_grade;			/* default spool grade character */
 extern int open_retries;		/* max open retries on startup file */
 extern int open_interval;		/* sleep between open retries */
+extern int min_runq_grade;		/* minimum grade to process in queue run */
+extern int max_runq_grade;		/* maximum grade to process in queue run */
+extern int min_delivery_grade;		/* minimum grade to deliver */
+extern int max_delivery_grade;		/* maximum grade to deliver */
 extern char *config_file;		/* config file name */
 extern char *director_file;		/* directors file name */
 extern char *router_file;		/* routers file name */
@@ -71,6 +75,8 @@ extern int lock_by_name;		/* TRUE to use spool lockfiles */
 extern int queue_only;			/* true to queue but not deliver */
 extern int max_hop_count;		/* fail if hop_count exceeds this */
 extern char *delivery_mode_string;	/* string naming delivery mode */
+extern char *delivery_grades;		/* the msg grade range to be delivered */
+extern char *runq_grades;		/* the msg grade range in runq */
 extern char *smart_user;		/* default user for smartuser driver */
 extern char *smart_path;		/* default path for smarthost driver */
 extern char *smart_transport;		/* transport for smarthost driver */
@@ -97,6 +103,7 @@ extern char *auth_domains;		/* authoritative domain list */
 extern int tzoffset;			/* timezone offset for glotznet host */
 extern int tznodst;			/* true if no DST for glotznet host */
 #endif /* GLOTZNET */
+extern int rfc1413_query_timeout;      	/* Timeout on RFC1413 ident queries */
 
 /* external variables defined in default.c */
 extern struct director *directors;	/* configured directors */
@@ -170,6 +177,8 @@ extern char *sender_program;		/* name of program that spooled msg */
 #ifdef GLOTZNET
 extern char *glotzhost;			/* name of glotznet host */
 #endif /* GLOTZNET */
+extern char * ident_sender;		/* The calculated identity of the sender */
+extern char * ident_method;		/* Method used to determine ident_sender */
 
 /* external variables defined in modes.c */
 extern int daemon_pid;			/* pid of daemon process */
@@ -220,6 +229,8 @@ extern int cached_transports;		/* TRUE if cache_transports() called */
 /* external variables defined in route.c */
 extern int cached_routers;		/* TRUE if cache_routers() called */
 
+/* external variables defined in smtprecv.c */
+
 
 /*
  * External functions used in the smail program
@@ -265,6 +276,7 @@ extern char *expand_string();
 extern char **build_cmd_line();
 extern char *lc_fold();
 extern char *uc_fold();
+extern char *quote_fold();
 
 /* external functions defined in field.c */
 extern char *tokenize();
