@@ -1,4 +1,4 @@
-/* @(#)src/log.c	1.10 9/20/92 18:45:29 */
+/* @(#) $Id: log.c,v 1.11 1994/10/17 17:04:37 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -477,7 +477,7 @@ write_log(who, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(who, fmt, ap);
+	write_log_va(LOG_SYS, fmt, ap);
 	va_end(ap);
     }
     if (who & LOG_PANIC) {
@@ -486,7 +486,7 @@ write_log(who, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(who, fmt, ap);
+	write_log_va(LOG_PANIC, fmt, ap);
 	va_end(ap);
     }
     if (who & LOG_MLOG) {
@@ -495,7 +495,7 @@ write_log(who, fmt, va_alist)
 #else
 	va_start(ap);
 #endif
-	write_log_va(who, fmt, ap);
+	write_log_va(LOG_MLOG, fmt, ap);
 	va_end(ap);
     }
 }
@@ -556,7 +556,7 @@ write_log_va(who, fmt, ap)
 	if (logfile == NULL || panicfile == NULL) {
 	    open_system_logs();		/* if system log not open, open it */
 	}
-	(void)fprintf(logfile, "%s: ", time_stamp());
+	(void)fprintf(logfile, "\n%s: ", time_stamp());
 #ifdef GLOTZNET
 	(void)fprintf(logfile, "%s: ", glotzhost);
 #endif /* GLOTZNET */
@@ -579,7 +579,7 @@ write_log_va(who, fmt, ap)
 	if (panicfile == NULL) {
 	    open_system_logs();		/* if system log not open, open it */
 	}
-	(void)fprintf(panicfile, "%s: ", time_stamp());
+	(void)fprintf(panicfile, "\n%s: ", time_stamp());
 #ifdef GLOTZNET
 	(void)fprintf(panicfile, "%s: ", glotzhost);
 #endif /* GLOTZNET */
