@@ -1,4 +1,4 @@
-/* @(#)src/modes.c	1.38 9/20/92 12:54:56 */
+/* @(#) $Id: modes.c,v 1.41 1994/10/25 12:14:13 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -502,7 +502,9 @@ perform_deliver_mail()
     log_spool_errors();
 
     /* if we are only queuing, we have gone as far as we need to */
-    if (queue_only || deliver_mode == QUEUE_MESSAGE) {
+    if (queue_only || deliver_mode == QUEUE_MESSAGE 
+	|| (msg_grade < min_delivery_grade) 
+	|| (msg_grade > max_delivery_grade)) {
 	if (debug && dont_deliver) {
 	    /* unless we are debugging as well */
 	    DEBUG(DBG_MAIN_LO,
@@ -601,6 +603,13 @@ deliver_mail()
     struct identify_addr *sent_errors;	/* addresses previously sent errors */
     struct defer_addr *defer_errors;	/* previous defer messages */
 
+    /*
+     * This code attempts to optimise the reprocessing of queued mail
+     * by putting sucessfully delivered addresses into the hash table
+     * to prevent them being put through the routers.
+     */
+    hash_predelivered_addresses();
+
     /*
      * preparse all of the recipient addresses given as arguments.
      * If we are extracting addresses from the header, then
@@ -760,6 +769,7 @@ deliver_mail()
 	 * occured, then we are done with the message.  Thus, unlink
 	 * the message and the per-message log file.
 	 */
+	write_log(LOG_SYS, "Completed.");
 	unlink_spool();
 	unlink_msg_log();
     }
@@ -927,7 +937,7 @@ daemon_mode()
 	int len = sizeof(from);
 
 	DEBUG1(DBG_MAIN_MID, "listening on port %d...\n",
-	       ntohs(smtp_service->s_port));
+	       ntohs(port));
 
 #ifdef ISC_ACCEPT_BUG
 	FD_ZERO(&fds_used);
@@ -1752,6 +1762,7 @@ do_smtp(in, out)
 {
     char **files;			/* files returned by receive_smtp() */
     int cnt;				/* count of files */
+    int entry_grade;
     int i;
 
     /* cache some interesting things */
@@ -1800,50 +1811,55 @@ do_smtp(in, out)
 
     if (spool_fn) {
 	/* last file still open, finish processing it */
-	char **argv;			/* args from read_message() */
-	int pid;			/* pid of child process */
+	/* Check to see if this grade should be delivered immediately */
+	entry_grade = spool_fn[strlen(spool_fn) - 1];
+	if ((entry_grade >= min_delivery_grade) 
+	    && (entry_grade <= max_delivery_grade)) {
 
-	/* make a child process */
-	/* unlock the message in the parent process (see lock_message()) */
-	unlock_message();
-	pid = fork_wait();
-	if (pid < 0) {
-	    /* can't fork(), try again later for all messages */
-	    if (errfile) {
-		(void)fprintf(errfile,
-			      "%s: fork() failed: %s, try again later\n",
-			      program, strerrno());
-		(void)fflush(errfile);
-	    }
-	    return;
-	}
-	if (pid == 0) {
-	    /* in child process, process the message */
-	    if (lock_message() == FAIL) {
-		/* somebody else grabbed the lock, assume they will deliver */
-		exit(0);
-	    }
-	    argv = read_message();
+	    char **argv;		/* args from read_message() */
+	    int pid;			/* pid of child process */
 
-	    if (argv == NULL) {
+	    /* make a child process */
+	    /* unlock the message in the parent process (see lock_message()) */
+	    unlock_message();
+	    pid = fork_wait();
+	    if (pid < 0) {
+		/* can't fork(), try again later for all messages */
+		if (errfile) {
+		    (void)fprintf(errfile,
+				  "%s: fork() failed: %s, try again later\n",
+				  program, strerrno());
+		    (void)fflush(errfile);
+		}
+		return;
+	    }
+	    if (pid == 0) {
+		/* in child process, process the message */
+		if (lock_message() == FAIL) {
+		    /* somebody else grabbed the lock, assume they will deliver */
+		    exit(0);
+		}
+		argv = read_message();
+
+		if (argv == NULL) {
+		    exit(exitvalue);
+		}
+
+		/* process arguments from the spool file */
+		process_args(argv);
+
+		/* perform delivery */
+		deliver_mail();
+
+		/* close the system-wide log files */
+		close_system_logs();
+
+		/* all done with the message */
 		exit(exitvalue);
 	    }
-
-	    /* process arguments from the spool file */
-	    process_args(argv);
-
-	    /* perform delivery */
-	    deliver_mail();
-
-	    /* close the system-wide log files */
-	    close_system_logs();
-
-	    /* all done with the message */
-	    exit(exitvalue);
 	}
-
 	/*
-	 * in the parent
+	 * in the parent - or if queued instead
 	 *
 	 * XXX - we need to close the open spool file, but going through
 	 *       routines in spool.c would duplicate efforts already
@@ -1858,9 +1874,15 @@ do_smtp(in, out)
      * process the remaining files
      */
     for (i = 0; i < cnt; i++) {
-	/* process_spool_file only returns FAIL on fork() failures */
-	if (process_spool_file(files[i]) == FAIL) {
-	    return ;
+	/* Check to see if this grade should be delivered immediately */
+	entry_grade = (files[i])[strlen(files[i]) - 1];
+	if ((entry_grade >= min_delivery_grade) 
+	    && (entry_grade <= max_delivery_grade)) {
+
+	    /* process_spool_file only returns FAIL on fork() failures */
+	    if (process_spool_file(files[i]) == FAIL) {
+		return ;
+	    }
 	}
     }
 }
