@@ -1,4 +1,4 @@
-/* @(#)src/retry.c	1.21 9/20/92 18:46:27 */
+/* @(#) $Id: retry.c,v 1.22 1994/10/17 17:04:37 nm4 Exp $ */
 
 /*
  * retry.c:
@@ -685,7 +685,7 @@ tryfile_name(transport, host, create_dirs)
     char *host;
     int create_dirs;
 {
-    static size_t pathmax = 0;
+    static int pathmax = 0;
     static struct str path;
     static int inited = FALSE;
 
@@ -725,7 +725,7 @@ tryfile_name(transport, host, create_dirs)
 	return NULL;
     }
 
-    if (strlen(host) <= pathmax) {
+    if ((int)strlen(host) <= pathmax) {
 	if (tryfile_cat(&path, host, strlen(host), TRUE, FALSE,
 			create_dirs) == FAIL)
 	{
@@ -897,11 +897,11 @@ write_error(fd, tryfile, error)
 	(void) unlink(tryfile);
     } else {
 	char *e;
-	size_t elen;
+	int elen;
 
 	/* write error code and message */
 	e = xprintf("%ld %s\n", error->info & ERR_MASK, error->message);
-	elen = strlen(e);
+	elen = (int)strlen(e);
 	(void) lseek(fd, 0L, 0);
 	(void) write(fd, e, elen + 1);
 	(void) xfree(e);
@@ -928,7 +928,7 @@ read_error(fd, tryfile, error)
     struct stat statbuf;
     char *buf, *errmsg, *p;
     long errcode;
-    size_t len;
+    int len;
 
     /* assume that we can't read the file */
     error->info = ERR_173;
@@ -938,7 +938,7 @@ read_error(fd, tryfile, error)
     if (fstat(fd, &statbuf) == -1 || statbuf.st_size > 0x7FFF) {
 	return;
     }
-    len = (size_t)statbuf.st_size;
+    len = (int)statbuf.st_size;
     buf = xmalloc(len + 1);
     if (read(fd, buf, len + 1) != len) {
 	xfree(buf);
