@@ -1,4 +1,4 @@
-/* @(#)src/routers/smarthost.c	1.6 9/6/92 03:47:23 */
+/* @(#) $Id: smarthost.c,v 1.7 1994/10/17 17:04:28 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -162,8 +162,8 @@ rtd_smarthost(rp, in, out, defer, fail)
  */
 /*ARGSUSED*/
 void
-rtv_smarthost(dp, in, retry, okay, defer, fail)
-    struct director *dp;		/* director entry */
+rtv_smarthost(rp, in, retry, okay, defer, fail)
+    struct router *rp;		/* director entry */
     struct addr *in;			/* input local-form addrs */
     struct addr **retry;		/* output list of unmatched addrs */
     struct addr **okay;			/* output list of verified addrs */
@@ -172,11 +172,14 @@ rtv_smarthost(dp, in, retry, okay, defer, fail)
 {
     register struct addr *cur;		/* current addr being processed */
     struct addr *next;			/* next addr to process */
+    struct smarthost_private *priv = (struct smarthost_private *)rp->private;
 
     for (cur = in; cur; cur = next) {
 	next = cur->succ;
 
 	if ((cur->flags & ADDR_SMARTHOST) ||
+	    (priv->path == NULL && priv->host == NULL &&
+	     smart_path == NULL) ||
 	    match_auth_domains(cur->target)) {
 	    /* no match if we are disabling smarthost routing here */
 	    cur->succ = *retry;
