@@ -1,4 +1,4 @@
-/* @(#)src/smailconf.c	1.15 9/16/92 09:10:36 */
+/* @(#) $Id: smailconf.c,v 1.17 1994/10/24 13:12:25 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -66,6 +66,7 @@ static struct attr_table conf_attributes[] = {
     { "console", t_string, NULL, (tup *)&cons_fn, 0 },
     { "copying_file", t_string, NULL, (tup *)&copying_file, 0 },
     { "date_field", t_string, NULL, (tup *)&date_field, 0 },
+    { "delivery_grades", t_string, NULL, (tup *)&delivery_grades, 0 },
     { "delivery_mode", t_string, NULL, (tup *)&delivery_mode_string, 0 },
     { "director_file", t_string, NULL, (tup *)&director_file, 0 },
     { "domains", t_string, NULL, (tup *)&visible_domains, 0 },
@@ -113,6 +114,7 @@ static struct attr_table conf_attributes[] = {
     { "retry_interval", t_interval, NULL, (tup *)&retry_interval, 0 },
     { "return_path_field", t_string, NULL, (tup *)&return_path_field, 0 },
     { "router_file", t_string, NULL, (tup *)&router_file, 0 },
+    { "runq_grades", t_string, NULL, (tup *)&runq_grades, 0 },
     { "second_config_file", t_string, NULL, (tup *)&second_config_file, 0 },
     { "sender_env_variable", t_string, NULL, (tup *)&sender_env_variable, 0 },
     { "smail", t_string, NULL, (tup *)&smail, 0 },
@@ -135,6 +137,7 @@ static struct attr_table conf_attributes[] = {
     { "spool_mode", t_int, NULL, (tup *)&spool_mode, 0 },
     { "switch_percent_and_bang", t_boolean, NULL,
       (tup *)&switch_percent_and_bang, 0 },
+    { "rfc1413_query_timeout", t_int, NULL, (tup *)&rfc1413_query_timeout, 0 },
     { "transport_file", t_string, NULL, (tup *)&transport_file, 0 },
     { "trusted", t_string, NULL, (tup *)&trusted, 0 },
     { "trusted_users", t_string, NULL, (tup *)&trusted, 0 },
