@@ -108,7 +108,7 @@ static int copy_old_spool();
 static void log_message();
 
 /* functions imported from libc */
-/* long lseek(); */
+long lseek();
 struct tm *localtime();
 struct tm *gmtime();
 char *ctime();
