@@ -197,7 +197,7 @@ char *
 strerrno()
 {
     static char misc_err[50];		/* used when sprintf must be used */
-/*  extern char *sys_errlist[];		/* list of error strings */
+    extern char *sys_errlist[];		/* list of error strings */
     extern int sys_nerr;		/* number of entries in sys_errlist */
 
     if (errno > sys_nerr || errno < 0) {
