@@ -1,4 +1,4 @@
-/* @(#)src/transports/smtplib.c	1.13 9/20/92 18:46:35 */
+/* @(#) $Id: smtplib.c,v 1.14 1994/10/17 17:04:33 nm4 Exp $ */
 
 /*
  *    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
@@ -174,14 +174,17 @@ smtp_startup(smtpb, error_p)
  * Return:
  *	SUCCEED	- more smtp messages can be sent.
  *	FAIL	- don't try to send any more messages.
+ *
+ * For FAIL, return a filled-in error structure.
  */
 int
-smtp_send(smtpb, addr, succeed, defer, fail)
+smtp_send(smtpb, addr, succeed, defer, fail, error_p)
     struct smtp *smtpb;			/* SMTP description block */
     struct addr *addr;			/* list of recipient addresses */
     struct addr **succeed;		/* successful addresses */
     struct addr **defer;		/* addresses to be retried */
     struct addr **fail;			/* failed addresses */
+    struct error **error_p;		/* error description */
 {
     register int reply;			/* reply code from SMTP commands */
     char *reply_text;			/* text of reply */
@@ -222,11 +225,13 @@ smtp_send(smtpb, addr, succeed, defer, fail)
 			       smtp_out.p, smtp_out.i, &reply_text);
 
     if (REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN) {
-	insert_addr_list(addr, defer, try_again(smtpb->tp, reply_text));
+	*error_p = try_again(smtpb->tp, reply_text);
+	insert_addr_list(addr, defer, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     } else if (REPLY_GROUP(reply) == NEGATIVE_FAILED) {
-	insert_addr_list(addr, fail, fatal_error(tp, reply_text));
+	*error_p = fatal_error(tp, reply_text);
+	insert_addr_list(addr, fail, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     }
@@ -251,19 +256,18 @@ smtp_send(smtpb, addr, succeed, defer, fail)
 	reply = wait_write_command(smtpb, smtpb->long_timeout,
 				   smtp_out.p, smtp_out.i, &reply_text);
 
-	if (reply == REPLY_STORAGE_FULL) {
-	    insert_addr_list(cur, defer, remote_full(tp, reply_text));
-	    next = NULL;
-	} else if (REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN) {
-	    struct error *error;
-
-	    error = try_again(smtpb->tp, reply_text);
-	    insert_addr_list(cur, defer, error);
-	    insert_addr_list(okay, defer, error);
+	if (reply == REPLY_STORAGE_FULL
+	    || REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN)
+	{
+	    *error_p = (reply == REPLY_STORAGE_FULL)?
+		remote_full(tp, reply_text):
+		try_again(smtpb->tp, reply_text);
+	    insert_addr_list(cur, defer, *error_p);
+	    insert_addr_list(okay, defer, *error_p);
 	    do_smtp_shutdown(smtpb, reply);
 	    return FAIL;
 	} else if (REPLY_GROUP(reply) == NEGATIVE_FAILED) {
-	    cur->error =  remote_bad_address(tp, reply_text);
+	    cur->error = remote_bad_address(tp, reply_text);
 	    cur->succ = *fail;
 	    *fail = cur;
 	} else {
@@ -285,14 +289,16 @@ smtp_send(smtpb, addr, succeed, defer, fail)
 			       DATA, sizeof(DATA) - 1, &reply_text);
 
     if (REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN) {
-	insert_addr_list(okay, defer, try_again(tp, reply_text));
+	*error_p = try_again(tp, reply_text);
+	insert_addr_list(okay, defer, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     }
 
     if (reply != REPLY_START_DATA && reply != REPLY_OK) {
 	/* fatal error, return message to sender */
-	insert_addr_list(okay, fail, fatal_error(tp, reply_text));
+	*error_p = fatal_error(tp, reply_text);
+	insert_addr_list(okay, fail, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     }
@@ -304,13 +310,15 @@ smtp_send(smtpb, addr, succeed, defer, fail)
     success = write_message(smtpb->out, tp, addr);
 
     if (success == WRITE_FAIL) {
-	insert_addr_list(okay, defer, write_failed(tp));
+	*error_p = write_failed(tp);
+	insert_addr_list(okay, defer, *error_p);
 
 	/* assume connection has gone away */
 	return FAIL;
     }
     if (success == READ_FAIL) {
-	insert_addr_list(okay, defer, read_failed(tp));
+	*error_p = read_failed(tp);
+	insert_addr_list(okay, defer, *error_p);
 
 	/* okay to advance to the next message */
 	return SUCCEED;
@@ -321,14 +329,16 @@ smtp_send(smtpb, addr, succeed, defer, fail)
 			       DATA_END, sizeof(DATA_END)-1, &reply_text);
 
     if (REPLY_GROUP(reply) == NEGATIVE_TRY_AGAIN) {
-	insert_addr_list(okay, defer, try_again(tp, reply_text));
+	*error_p = try_again(tp, reply_text);
+	insert_addr_list(okay, defer, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     }
 
     if (reply != REPLY_OK) {
 	/* fatal error, return message to sender */
-	insert_addr_list(okay, fail, fatal_error(tp, reply_text));
+	*error_p = fatal_error(tp, reply_text);
+	insert_addr_list(okay, fail, *error_p);
 	do_smtp_shutdown(smtpb, reply);
 	return FAIL;
     }
